==> dl.php?src=linea21_1_4.zip: linea21/scale/help.php <==
<?php
/**
 * @package linea21.core
 * @subpackage scale
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$dirbox = $dir . "/help";
?>
<br
	class="brendstep brendstepfooter" />
<div class="headerhelp"><a href="#aideencre"
	title="<?php echo _t('help','title');?>" class="help_ico aideencre"></a>
<div class="help"><a href="#aideencre" class="aideencre" id="aideencre"
	title="<?php echo _t('help','title');?>"><?php echo _t('help','title');?></a>
<?if ($todo == 'add') {
  ?>
<div id="aide">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','add');?></p>
<ul>
	<li><?php echo _t('scale','help_add1');?></li>
	<li><?php echo _t('scale','help_add2');?></li>
	<li><?php echo _t('scale','help_add3');?></li>
	<li><?php echo _t('scale','help_add4');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','det');?></p>
<ul>
	<li><?php echo _t('scale','help_det1');?></li>
	<li><?php echo _t('scale','help_det2');?></li>
	<li><?php echo _t('scale','help_det3');?></li>
</ul>

    <?php }
    if ($todo == 'mod') {
      ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','mod');?></p>
<ul>
	<li><?php echo _t('scale','help_mod1');?></li>
	<li><?php echo _t('scale','help_mod2');?></li>
	<li><?php echo _t('scale','help_mod3');?></li>
</ul>
      <?php }
      if ($todo == 'list') {
        ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','list');?></p>
<ul>
	<li><?php echo _t('scale','help_list1');?></li>
	<li><?php echo _t('scale','help_list2');?></li>
	<li><?php echo _t('scale','help_list3');?></li>
	<li><?php echo _t('scale','help_list4');?></li>
	<li><?php echo _t('scale','help_list5');?></li>
</ul>
        <?php }
        if ($todo == 'sup') {
          ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','sup');?></p>
<ul>
	<li><?php echo _t('scale','help_sup1');?></li>
	<li><?php echo _t('scale','help_sup2');?></li>
	<li><?php echo _t('scale','help_sup3');?></li>
</ul>
          <?php }
          include_once(THEME_ADMIN_PATH."footer_content.php");
?>

==> dl.php?src=linea21_1_6.zip: linea21/scale/help.php <==
<?php
/**
 * @package linea21.core
 * @subpackage scale
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

$dirbox = $dir . "/help";
?>
<br
	class="brendstep brendstepfooter" />
<div class="headerhelp"><a href="#aide-ancre"
	title="<?php echo _t('help','title');?>" class="help_ico aide-ancre"></a>
<div class="help"><a href="#aide-ancre" class="aide-ancre" id="aide-ancre"
	title="<?php echo _t('help','title');?>"><?php echo _t('help','title');?></a>
<?php if ($todo == 'add') {
  ?>
<div id="aide">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','add');?></p>
<ul>
	<li><?php echo _t('scale','help_add1');?></li>
	<li><?php echo _t('scale','help_add2');?></li>
	<li><?php echo _t('scale','help_add3');?></li>
	<li><?php echo _t('scale','help_add4');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','det');?></p>
<ul>
	<li><?php echo _t('scale','help_det1');?></li>
	<li><?php echo _t('scale','help_det2');?></li>
	<li><?php echo _t('scale','help_det3');?></li>
</ul>

    <?php }
    if ($todo == 'mod') {
      ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','mod');?></p>
<ul>
	<li><?php echo _t('scale','help_mod1');?></li>
	<li><?php echo _t('scale','help_mod2');?></li>
	<li><?php echo _t('scale','help_mod3');?></li>
</ul>
      <?php }
      if ($todo == 'list') {
        ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','list');?></p>
<ul>
	<li><?php echo _t('scale','help_list1');?></li>
	<li><?php echo _t('scale','help_list2');?></li>
	<li><?php echo _t('scale','help_list3');?></li>
	<li><?php echo _t('scale','help_list4');?></li>
	<li><?php echo _t('scale','help_list5');?></li>
</ul>
        <?php }
        if ($todo == 'sup') {
          ?>
<div id="aide" style="display: none">
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('scale','sup');?></p>
<ul>
	<li><?php echo _t('scale','help_sup1');?></li>
	<li><?php echo _t('scale','help_sup2');?></li>
	<li><?php echo _t('scale','help_sup3');?></li>
</ul>
          <?php }
          include_once(THEME_ADMIN_PATH."footer_content.php");
?>
